"""fsuipc

This module provides a is simple Python client wrapper around the FSUIPC C
SDK, which allows third-party programs to interact with the "inner workings"
of popular flight simulator software.

Fsuipc is built on top of (and includes) pyuipc, by István Váradi
(ivaradi@varadiistvan.hu).

Basic Usage:

    from fsuipc import FSUIPC


    with FSUIPC() as fsuipc:
        prepared = fsuipc.prepare_data([
            (0x560, "l"),
            (0x568, "l"),
            (0x570, "l")
        ], True)

        while True:
            latitude, longitude, altitude = prepared.read()

            print(f"Latitude: {latitude}")
            print(f"Longitude: {longitude}")
            print(f"Altitude: {altitude}")

            input("Press ENTER to read again")
"""

from pyuipc import ERR_OK, ERR_OPEN, ERR_NOFS, ERR_REGMSG, ERR_ATOM, ERR_MAP, ERR_VIEW, ERR_VERSION
from pyuipc import ERR_WRONGFS, ERR_NOTOPEN, ERR_NODATA, ERR_TIMEOUT, ERR_SENDMSG, ERR_DATA
from pyuipc import ERR_RUNNING, ERR_SIZE
from pyuipc import SIM_ANY, SIM_FS98, SIM_FS2K, SIM_CFS2, SIM_CFS1, SIM_FLY, SIM_FS2K2, SIM_FS2K4
from pyuipc import SIM_FSX, SIM_ESP, SIM_P3D, SIM_FSX64, SIM_P3D64, SIM_FS2020
from pyuipc import FSUIPCException

from fsuipc.fsuipc import FSUIPC
from fsuipc.prepared_data import PreparedData

__all__ = [
    "ERR_OK", "ERR_OPEN", "ERR_NOFS", "ERR_REGMSG", "ERR_ATOM", "ERR_MAP", "ERR_VIEW",
    "ERR_VERSION", "ERR_WRONGFS", "ERR_NOTOPEN", "ERR_NODATA", "ERR_TIMEOUT", "ERR_SENDMSG",
    "ERR_DATA", "ERR_RUNNING", "ERR_SIZE",
    "SIM_ANY", "SIM_FS98", "SIM_FS2K", "SIM_CFS2", "SIM_CFS1", "SIM_FLY", "SIM_FS2K2", "SIM_FS2K4",
    "SIM_FSX", "SIM_ESP", "SIM_P3D", "SIM_FSX64", "SIM_P3D64", "SIM_FS2020",
    "FSUIPCException",
    "FSUIPC", "PreparedData"
]



from os import path
import platform
import setuptools
import struct
import sys


with open(path.join(path.abspath(path.dirname(__file__)), "README.md"), "r", encoding="utf8") as fh:
    long_description = fh.read()


if platform.system() != "Windows":
    sys.stderr.write("This package only supports Windows platforms\n")
    exit(1)

if struct.calcsize("P") == 8:
    ipcuser_source = "src/UIPC64_SDK_C_version2/IPCuser64.c"
    include_dir = "src/UIPC64_SDK_C_version2"
else:
    ipcuser_source = "src/UIPC_SDK_C/IPCuser.c"
    include_dir = "src/UIPC_SDK_C"


setuptools.setup(
    name="fsuipc",
    version="1.3.0",
    author="Tim Jensen",
    author_email="tim.l.jensen@gmail.com",
    description="Client wrapper for FSUIPC",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/tjensen/fsuipc",
    project_urls={
        "Source": "https://github.com/tjensen/fsuipc",
        "Tracker": "https://github.com/tjensen/fsuipc/issues"
    },
    keywords=["flight", "simulator", "pyuipc"],
    packages=["fsuipc", "pyuipc-stubs"],
    package_data={
        "fsuipc": ["py.typed"],  # PEP 561
        "pyuipc-stubs": ["__init__.pyi"]
    },
    zip_safe=False,  # Enables mypy to find the installed package
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Environment :: Win32 (MS Windows)",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Games/Entertainment :: Simulation"
    ],
    python_requires=">=3.5",
    setup_requires=["wheel"],
    ext_modules=[setuptools.Extension(
        name="pyuipc",
        sources=[
            ipcuser_source,
            "src/UIPC_SDK_Python/pyuipc.cc"
        ],
        include_dirs=[include_dir],
        libraries=["user32"])]
)
